
*************
Python module
*************

Support functions
-----------------

.. autosummary::

    shelephant.FlattenList
    shelephant.Squash

YAML handling
-------------

.. autosummary::

    shelephant.YamlRead
    shelephant.YamlDump
    shelephant.YamlPrint
    shelephant.YamlGetItem

File-path operations
--------------------

.. autosummary::

    shelephant.CheckAllIsFile
    shelephant.PrefixPaths
    shelephant.ChangeRootOfRelativePaths
    shelephant.GetDeepestPaths
    shelephant.DirNames
    shelephant.MakeDir
    shelephant.MakeDirs
    shelephant.OverWrite
    shelephant.GetSHA256
    shelephant.GetChecksums

Copy functions
--------------

.. autosummary::

    shelephant.IsOnRemote
    shelephant.CopyFromRemote
    shelephant.CopyToRemote
    shelephant.RsyncFromRemote
    shelephant.RsyncToRemote
    shelephant.ShelephantCopy
    shelephant.ShelephantCopySSH

Formatted print
---------------

.. autosummary::

    shelephant.Theme
    shelephant.String


Details
-------

.. automodule:: shelephant
  :members:

